==> haskell-yesod-form-1.7.9-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-J4BOHKq8LNv60cvLwTWQsq
key:                  yesod-form-1.7.9-J4BOHKq8LNv60cvLwTWQsq
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  f03ac09f7733ea0010c8fbb4e5704694
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-J4BOHKq8LNv60cvLwTWQsq
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y
    attoparsec-0.14.4-53YjHEyIcZv40S6MstOLSz base-4.17.2.1
    blaze-builder-0.4.3-KajDOuS86PHBEcDCbLATP7
    blaze-html-0.9.2.0-Af5P3A2URAm8PEOIhy6b3k
    blaze-markup-0.8.3.0-Alr6JP17MQvDFN7aUk8LfK
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09
    email-validate-2.3.2.21-FZuqd1crD2F8hpgEvcgOqC
    network-uri-2.6.4.2-9UqT53JjEGDF2lVDrQUMu1
    persistent-2.14.5.1-ApXi6yyhXCbC14J2G5agZ9
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    shakespeare-2.1.3-C4PzgEs43SJ2cv9Csuh3LC text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-4XAAckw9HTnIyst5cAezpH
    xss-sanitize-0.3.7.2-3tgxmDAGRDuBy6fKNGvYCF
    yesod-core-1.6.27.1-EyZghhvLerL2tW5N4BMkCJ
    yesod-persistent-1.6.0.8-2RmQgHOAgcG2Vm7jwFo8Tz

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.7.9-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-LUa1guWiVP9JLAYUNHIzRz
key:                  yesod-form-1.7.9-LUa1guWiVP9JLAYUNHIzRz
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  fe00749fe2e25742a39c0f3dd67b5874
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-LUa1guWiVP9JLAYUNHIzRz
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y
    attoparsec-0.14.4-53YjHEyIcZv40S6MstOLSz base-4.17.2.1
    blaze-builder-0.4.3-KajDOuS86PHBEcDCbLATP7
    blaze-html-0.9.2.0-Af5P3A2URAm8PEOIhy6b3k
    blaze-markup-0.8.3.0-Alr6JP17MQvDFN7aUk8LfK
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.2-6Zl8APX45CF9ONl13lbZ09
    email-validate-2.3.2.21-FZuqd1crD2F8hpgEvcgOqC
    network-uri-2.6.4.2-9UqT53JjEGDF2lVDrQUMu1
    persistent-2.14.5.1-ApXi6yyhXCbC14J2G5agZ9
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    shakespeare-2.1.3-C4PzgEs43SJ2cv9Csuh3LC text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-4XAAckw9HTnIyst5cAezpH
    xss-sanitize-0.3.7.2-3tgxmDAGRDuBy6fKNGvYCF
    yesod-core-1.6.27.1-5hnBS0Z2Jx2LBqBQo2mX3X
    yesod-persistent-1.6.0.8-8rWBeP4nrF0HuEnqpFzlnF

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
